@@ -1,7 +1,7 @@
 package Perinci::To::Doc::Role::Section;
 
-our $DATE = '2020-10-20'; # DATE
-our $VERSION = '0.874'; # VERSION
+our $DATE = '2021-02-21'; # DATE
+our $VERSION = '0.875'; # VERSION
 
 use 5.010;
 use Log::ger;
@@ -111,7 +111,7 @@ Perinci::To::Doc::Role::Section - Role for class that generates documentation wi
 
 =head1 VERSION
 
-This document describes version 0.874 of Perinci::To::Doc::Role::Section (from Perl distribution Perinci-To-Doc), released on 2020-10-20.
+This document describes version 0.875 of Perinci::To::Doc::Role::Section (from Perl distribution Perinci-To-Doc), released on 2021-02-21.
 
 =head1 DESCRIPTION
 
@@ -180,7 +180,7 @@ Source repository is at L<https://github.com/perlancar/perl-Perinci-To-Doc>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-To-Doc>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Perinci-To-Doc/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -199,7 +199,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
